@@ -29,9 +29,18 @@ F = layout.form.FormField
 
 # MENU ENTRIES ---------------------------------------------------------------------
 
+menu.registeritem(
+    menu.Item(
+        Link(
+            reverse("core.vocabulary.browse"),
+            basxconnect.core.models.Vocabulary._meta.verbose_name_plural,
+        ),
+        menu.admingroup,
+    )
+)
+
 persongroup = menu.Group(_("Persons"), iconname="group")
 settingsgroup = menu.Group(_("Settings"), iconname="settings", order=100)
-admingroup = DevGroup(_("Administration"), iconname="network--3--reference", order=500)
 
 menu.registeritem(
     menu.Item(
@@ -69,37 +78,3 @@ menu.registeritem(
         settingsgroup,
     )
 )
-
-menu.registeritem(
-    menu.Item(
-        Link(
-            reverse("core.vocabulary.browse"),
-            basxconnect.core.models.Vocabulary._meta.verbose_name_plural,
-        ),
-        admingroup,
-    )
-)
-
-menu.registeritem(
-    SuperUserItem(
-        Link(
-            reverse("basxconnect.core.views.admin_views.maintenancesettings"),
-            _("Maintenance"),
-        ),
-        admingroup,
-    )
-)
-
-menu.registeritem(
-    menu.Item(
-        Link(
-            reverse("systeminformation"),
-            _("System Information"),
-        ),
-        admingroup,
-    )
-)
-
-menu.registeritem(
-    SuperUserItem(Link(reverse("admin:index"), _("Django Admin")), admingroup)
-)
