@@ -21,7 +21,16 @@ def languages_choices(field, request, instance):
     return settings.PREFERRED_LANGUAGES
 
 
-class MailingPreferences(models.Model):
+class SynchronizationResult(models.Model):
+    total_synchronized_persons = models.IntegerField(
+        null=True, verbose_name=_("Number of persons in the mailer segment")
+    )
+    sync_completed_datetime = models.DateTimeField(
+        null=True, verbose_name=_("Date and time")
+    )
+
+
+class Subscription(models.Model):
     email = models.OneToOneField(Email, on_delete=models.CASCADE)
     status = models.CharField(
         max_length=50,
@@ -41,10 +50,12 @@ class MailingPreferences(models.Model):
     )  # mitigate up-stream bug
     language.lazy_choices = languages_choices
 
-
-class SynchronizationResult(models.Model):
-    total_synchronized_persons = models.IntegerField(null=True)
-    sync_completed_datetime = models.DateTimeField(null=True)
+    latest_sync = models.ForeignKey(
+        SynchronizationResult,
+        related_name="synchronized_subscription",
+        on_delete=models.SET_NULL,
+        null=True,
+    )
 
 
 class SynchronizationPerson(models.Model):
@@ -54,7 +65,21 @@ class SynchronizationPerson(models.Model):
     email = models.CharField(max_length=100)
     first_name = models.CharField(_("First Name"), max_length=255, blank=True)
     last_name = models.CharField(_("Last Name"), max_length=255, blank=True)
-    successfully_added = models.BooleanField(models.BooleanField)
+
+    NEW = "new"
+    SKIPPED = "import_error"
+    PREVIOUSLY_SYNCED = "synced_previously"
+    SYNC_STATUS_CHOICES = [
+        (NEW, _("Newly added to BasxConnect")),
+        (SKIPPED, _("Not added to BasxConnect")),
+        (PREVIOUSLY_SYNCED, _("Synchronized previously but not this time")),
+    ]
+    sync_status = models.CharField(
+        _("Synchronization Status"),
+        choices=SYNC_STATUS_CHOICES,
+        max_length=255,
+        blank=True,
+    )
 
     def __str__(self):
         return self.email
